unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, TeeGDIPlus, StdCtrls, ExtCtrls, TeEngine, TeeProcs, Chart;

type
  TForm1 = class(TForm)
    Chart1: TChart;
    Image1: TImage;
    Memo1: TMemo;
    BEdit: TButton;
    BRun: TButton;
    procedure FormCreate(Sender: TObject);
    procedure BEditClick(Sender: TObject);
    procedure BRunClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

uses Series, TeeDownSampling, EditChar, Diagnostics, TimeSpan;

var sourceSeries: TFastLineSeries;

procedure TForm1.BEditClick(Sender: TObject);
begin
  EditChart(Self, Chart1);
end;

procedure TForm1.BRunClick(Sender: TObject);

  procedure CheckExport(ATitle: String);
  var metaFile: TMetafile;
      stopWatch: TStopwatch;
      elapsed: TTimeSpan;
      seconds: Double;
  begin
    stopWatch:=TStopwatch.Create;
    stopWatch.Start;

    metaFile:=Chart1.TeeCreateMetafile(True, Rect(0,0,Image1.Width, Image1.Height));
    Image1.Picture.Assign(metaFile);

    elapsed:=stopWatch.Elapsed;
    seconds:=elapsed.TotalSeconds;
    Memo1.Lines.Add(ATitle+':');
    Memo1.Lines.Add('Took ' + FormatFloat('#,##0.##', seconds) + ' seconds');
    Memo1.Lines.Add('');

    stopWatch.Stop;
    metaFile.Free;
  end;

var downSampling: TDownSamplingFunction;
begin
  Memo1.Clear;
  Memo1.Lines.Add('Testing Metafile Performance with '+FormatFloat('#,##0.##',Chart1[0].Count)+' points in a FastLine Series...');
  Memo1.Lines.Add('');
  Screen.Cursor:=crHourGlass;
  Application.ProcessMessages;

  CheckExport('Default');

  with sourceSeries do
  begin
    DrawAllPoints:=False;
    DrawAllPointsStyle:=daMinMax;
  end;

  CheckExport('daMinMax');

  downSampling:=TDownSamplingFunction.Create(Self);
  downSampling.Tolerance:=4;
  downSampling.DownSampleMethod:=dsAverage;
  with Chart1.AddSeries(TFastLineSeries) do
  begin
    SetFunction(downSampling);
    DataSource:=sourceSeries;
    Color:=sourceSeries.Color;
    CheckDataSource;
  end;
  sourceSeries.Visible:=False;

  CheckExport('DownSampling function');

  with TFastLineSeries(Chart1[1]) do
  begin
    DrawAllPoints:=False;
    DrawAllPointsStyle:=daMinMax;
  end;

  CheckExport('DownSampling function with daMinMax');

  sourceSeries.Visible:=True;
  sourceSeries.DrawAllPoints:=True;
  Chart1.RemoveSeries(1);

  Screen.Cursor:=crDefault;
end;

procedure TForm1.FormCreate(Sender: TObject);
begin
  Chart1.View3D:=False;
  Chart1.Legend.Hide;
  Chart1.Gradient.Visible:=False;
  Chart1.Color:=clWhite;
  Chart1.Walls.Back.Gradient.Visible:=False;
  Chart1.Walls.Back.Color:=clWhite;

  sourceSeries:=TFastLineSeries(Chart1.AddSeries(TFastLineSeries));
  sourceSeries.FillSampleValues(1000000);

  Memo1.Clear;
end;

end.
